SellItems = {}
SellItems.name = "SellItems"
SellItems.sellTypes = {
	ITEMTYPE_ARMOR,
	ITEMTYPE_WEAPON,
	ITEMTYPE_GLYPH_ARMOR,
	ITEMTYPE_GLYPH_JEWELRY,
	ITEMTYPE_GLYPH_WEAPON
}
 
function SellItems:Initialize()
    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_OPEN_STORE, self.OnVendorOpen)
    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_CLOSE_STORE, self.OnVendorClose)
end

function SellItems.ShouldSell(slotId)
	local itemType = GetItemType(1,slotId)
	for i = 1, #SellItems.sellTypes do
		if SellItems.sellTypes[i] == itemType then
			return true
		end
	end
	return false
end
 
function SellItems.OnAddOnLoaded(event, addonName)
    if addonName == SellItems.name then
        SellItems:Initialize()
		SellItemsIndicatorOrnate:SetHidden(true)
		SellItemsIndicatorAll:SetHidden(true)
		SellItemsIndicatorLowerLevel:SetHidden(true)
		SellItemsIndicatorGreen:SetHidden(true)
		SellItemsIndicatorWhite:SetHidden(true)
    end
end
 
function SellItems.OnVendorOpen(event)
    SellItemsIndicatorOrnate:SetHidden(false)
	SellItemsIndicatorAll:SetHidden(false)
	SellItemsIndicatorLowerLevel:SetHidden(false)
	SellItemsIndicatorGreen:SetHidden(false)
	SellItemsIndicatorWhite:SetHidden(false)
end

function SellItems.OnVendorClose(event)
    SellItemsIndicatorOrnate:SetHidden(true)
	SellItemsIndicatorAll:SetHidden(true)
	SellItemsIndicatorLowerLevel:SetHidden(true)
	SellItemsIndicatorGreen:SetHidden(true)
	SellItemsIndicatorWhite:SetHidden(true)
end

function SellItems.SellGreen()
	d("Selling all items of green quality")
	local function filter(slotId)
		return SellItems.ShouldSell(slotId) and SellItems.QualityFilter(slotId, ITEM_QUALITY_MAGIC)
	end
	SellItems.Sell(filter)
end

function SellItems.SellWhite()
	d("Selling all items of white quality")
	local function filter(slotId)
		return SellItems.ShouldSell(slotId) and SellItems.QualityFilter(slotId, ITEM_QUALITY_NORMAL)
	end
	SellItems.Sell(filter)
end

function SellItems.QualityFilter(slotId,quality)
	local itemQuality = GetItemQuality(1,slotId)
	return itemQuality == quality
end

function SellItems.SellAll()
	d("Selling all items with value greater then 0")
	local function filter(slotId)
		return SellItems.ShouldSell(slotId)
	end
	SellItems.Sell(filter)
end

function SellItems.Sell(filter)
    local slotId = 0
    local bagsize = GetBagSize(1)
	local totalAmount = 0
	local itemCount = 0
	local goldIcon = ZO_Currency_GetPlatformFormattedGoldIcon()
    for slotId = 0,bagsize do
		local unlocked=not IsItemPlayerLocked(1,slotId)
		local link=GetItemLink(1,slotId,0)
		local itemPrice = GetItemLinkValue(link,false)
		if unlocked and itemPrice > 0 and filter(slotId) then
			local count = GetItemLinkStacks(link)
			SellInventoryItem(1,slotId,count)
			local value = GetItemSellValueWithBonuses(1,slotId)
			totalAmount = totalAmount + value * count
			itemCount = itemCount + count
			d("Sold: "  .. count .. "x " .. GetItemLink(1,slotId,1) .. " for " .. value .. goldIcon)
		end
	end
	d("Sold " .. itemCount .. " items for a total of " .. totalAmount .. goldIcon)
end

function SellItems.SellLowerLevel()
	local playerLevel = GetUnitLevel("player")
	d("Selling all items with level lesser then " .. playerLevel)
	local function filter(slotId)
		local itemLevel = GetItemRequiredLevel(1,slotId)
		return SellItems.ShouldSell(slotId) and itemLevel < playerLevel
	end
	SellItems.Sell(filter)
end

function SellItems.SellOrnate()
    d("Selling ornate items")
	local function filter(slotId)
		local trait = GetItemTrait(1,slotId)
        return trait == ITEM_TRAIT_TYPE_ARMOR_ORNATE or trait (1,slotId)==ITEM_TRAIT_TYPE_WEAPON_ORNATE or GetString("SI_ITEMTRAITTYPE",trait)=="Ornate"
	end
	SellItems.Sell(filter)
end

EVENT_MANAGER:RegisterForEvent(SellItems.name, EVENT_ADD_ON_LOADED, SellItems.OnAddOnLoaded)